import ConfigParser
import os
import shutil

class SogouConfig:
    def __copyIniFile__(self,filename):
        self.dist = os.path.join(self.__sogou_dir, filename)
        if not os.path.exists(self.dist):
            src = os.path.join(self.__datadir, "ibus-sogoupy/dict", filename)
            if os.path.exists(src):
                shutil.copyfile(src, self.dist)

    def skin_dir(self):
        from xdg import BaseDirectory
        self.__sogou_skin = os.path.join(BaseDirectory.xdg_config_home, "ibus/sogoupy/skin/")
        os.path.exists(self.__sogou_skin) or os.makedirs(self.__sogou_skin)

	return self.__sogou_skin

    def __init__(self):
        from xdg import BaseDirectory
        self.__sogou_dir = os.path.join(BaseDirectory.xdg_config_home, "ibus/sogoupy/SogouPY/")
    
        #check dir exist
        os.path.exists(self.__sogou_dir) or os.makedirs(self.__sogou_dir)

        #check file exist 
        self.__datadir= os.getenv("IBUS_DATAROOTDIR") or "/usr/share"

        #check env.ini file exist
        self.__env_file_path = os.path.join(self.__sogou_dir,"env.ini")
        self.__copyIniFile__("env.ini")

        #check Correction.ini file exist
        self.__correction_file_path = os.path.join(self.__sogou_dir,"Correction.ini")
        self.__copyIniFile__("Correction.ini")

        #check MoHuYin.ini file exist
        self.__mohuyin_file_path = os.path.join(self.__sogou_dir,"MoHuYin.ini")
        self.__copyIniFile__("MoHuYin.ini")

        #check Phrases.ini file exist
        self.__phrases_file_path = os.path.join(self.__sogou_dir,"Phrases.ini")
        self.__copyIniFile__("Phrases.ini")

        self.__init_env()
        self.__init_mohuyin()
        self.__init_correction()

    #env config file 
    def __init_env(self):
        print self.__env_file_path
        self.__env_cfg=ConfigParser.ConfigParser()
        self.__env_cfg.read(self.__env_file_path)
        self.__env_section_name="Setting"
        

    def SetEnvValue(self,Key,Value):
        #set value
        if Value == False:
            Value=0
        elif Value == True:
            Value=1
        self.__env_cfg.set(self.__env_section_name,Key,Value)
        #write and save
        cfgfile=open(self.__env_file_path,'w')
        self.__env_cfg.write(cfgfile)
        cfgfile.close()
        print "SetEnvValue"
            
    def ExistEnvKey(self,Key):
        return self.__env_cfg.has_option(self.__env_section_name,Key)

    def GetEnvValue(self,Key):
        if self.ExistEnvKey(Key):
            value=self.__env_cfg.get(self.__env_section_name,Key)
            if value=="0": #error if value==0
                return False
            else:
                return True
        #defalt value?? 
        return False

    #mohuyin
    def __init_mohuyin(self):
        print self.__mohuyin_file_path
        self.__mohuyin_cfg=ConfigParser.ConfigParser()
        self.__mohuyin_cfg.read(self.__mohuyin_file_path)
        self.__mohuyin_section_name='Fuzzy'
        

    def RemoveMoHuYinValue(self,Key):
        #remove option
        self.__mohuyin_cfg.remove_option(self.__mohuyin_section_name,Key)
        #write and save
        cfgfile=open(self.__mohuyin_file_path,'w')
        self.__mohuyin_cfg.write(cfgfile)
        cfgfile.close()


    def SetMoHuYinValue(self,Key,Value):
        if Value == False:
            Value=0
        elif Value == True:
            Value=1
        #check section

        #set value
        try:
            self.__mohuyin_cfg.set(self.__mohuyin_section_name,Key,Value)
        except:
            self.__mohuyin_cfg.add_section(self.__mohuyin_section_name)
            self.__mohuyin_cfg.set(self.__mohuyin_section_name,Key,Value) 

        #write and save
        cfgfile=open(self.__mohuyin_file_path,'w')
        self.__mohuyin_cfg.write(cfgfile)
        cfgfile.close()
            
    def GetMoHuYinValue(self,Key):
        return self.__mohuyin_cfg.get(self.__mohuyin_section_name,Key)


    def ModifyMoHuYinConfig(self,Key,Value,bAdd):
        if bAdd:
            self.SetMoHuYinValue(Key,Value)
        else:
            self.RemoveMoHuYinValue(Key)
            self.RemoveMoHuYinValue(Value)

    def ExistMoHuYinKey(self,Key):
        return self.__mohuyin_cfg.has_option(self.__mohuyin_section_name,Key)

    #correction
    def __init_correction(self):
        print self.__correction_file_path
        self.__correction_cfg=ConfigParser.ConfigParser()
        self.__correction_cfg.read(self.__correction_file_path)
        self.__correction_section_name='Correction'
        
    def RemoveCorrectionValue(self,Key):
        #remove option
        self.__correction_cfg.remove_option(self.__correction_section_name,Key)
        #write and save
        cfgfile=open(self.__correction_file_path,'w')
        self.__correction_cfg.write(cfgfile)
        cfgfile.close()

    def ExistCorrectionKey(self,Key):
        return self.__correction_cfg.has_option(self.__correction_section_name,Key)

    def SetCorrectionValue(self,Key,Value):
        #set value
        self.__correction_cfg.set(self.__correction_section_name,Key,Value)
        #write and save
        cfgfile=open(self.__correction_file_path,'w')
        self.__correction_cfg.write(cfgfile)
        cfgfile.close()

    def ModifyCorrectionConfig(self,Key,Value,bAdd):
        if bAdd:
            self.SetCorrectionValue(Key,Value)
        else:
            self.RemoveCorrectionValue(Key)
            self.RemoveCorrectionValue(Value)
            
    def GetCorrectionValue(self,Key):
        return self.__correction_cfg.get(self.__correction_section_name,Key)


#test env
def TestEnv():
    config=SogouConfig()
    v=config.GetEnvValue("MoHuYin") 
    print v
    config.SetEnvValue("Correction",0)

#test MoHuYin
def TestMoHuYin():
    config=SogouConfig()
    v=config.GetMoHuYinValue("z") 
    print v
    config.SetMoHuYinValue('n','l')
    config.RemoveMoHuYinValue('eng')

#test correction
def TestCorrection():
    config=SogouConfig()
    v=config.GetCorrectionValue("gn") 
    print v
    config.SetCorrectionValue('el','le')
    config.RemoveCorrectionValue('on')

if __name__ == '__main__':
    #TestCorrection()
    TestMoHuYin()
    
